#
# spec file for package php-pear-Auth_SASL
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pear_name  Auth_SASL

Name:           php-pear-Auth_SASL
Version:        1.2.0
Release:        1.4
Summary:        Abstraction of various SASL mechanism responses
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
URL:            https://pear.php.net/package/%{pear_name}
Source:         https://pear.php.net/get/%{pear_name}-%{version}.tgz
BuildRequires:  php-devel
BuildRequires:  php-pear
Requires:       php-pear
Provides:       php-pear(%{pear_name}) = %{version}
# PHP5 last used in openSUSE:Leap_42.3
Provides:       php5-pear-%{pear_name} = %{version}
Obsoletes:      php5-pear-%{pear_name} < %{version}
Provides:       php7-pear-%{pear_name} = %{version}
Obsoletes:      php7-pear-%{pear_name} < %{version}
BuildArch:      noarch

%description
Provides code to generate responses to common SASL mechanisms, including:
  - Digest-MD5
  - CramMD5
  - Plain
  - Anonymous
  - Login (Pseudo mechanism)

%prep
%setup -q -n %{pear_name}-%{version}
# move package.xml when needed
[ -f ../package.xml ] &&  mv ../package.xml . || :

%build

%install
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{php_pear_gen_filelist}

%post
if [ "$1" = "1" ]; then
  # on "rpm -ivh"
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi
if [ "$1" = "2" ]; then
  # on "rpm -Uvh"
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi

%postun
if [ "$1" = "0" ]; then
  # on "rpm -e"
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name} || :
fi

%files -f %{name}.files
%docdir %{pear_docdir}
%exclude %{pear_metadir}/.??*
%exclude %{pear_testdir}

%changelog
* Sat Jan 20 2024 Arjen de Korte <suse+build@de-korte.org>
- version 1.2.0
  * feature: PHP8.2 ready
  * bugfix: scram-sha-224 broken #14
  * task: mark authentication methods cram-md5, digest-md5, and login as
    deprecated #14
* Thu Dec  5 2019 Arjen de Korte <suse+build@de-korte.org>
- make package PHP version independent
- use correct macro to reference metadata (boo#1158112)
- clean-up spec, use https for downloading
* Tue Jan 29 2019 suse+build@de-korte.org
- Remove (Build)Requires php7-pear-Archive_Tar
- Only require php7-macros if needed
* Sat Aug 26 2017 jweberhofer@weberhofer.at
- Improve package, use php packaging macros
* Sat Aug 26 2017 jweberhofer@weberhofer.at
- Require php7-macros
* Sat Aug  5 2017 jweberhofer@weberhofer.at
- Splitted off PHP7 package
- version 1.1.0
  * Request #21033: PHP warning depreciated
* Sat Aug  5 2017 jweberhofer@weberhofer.at
- Simplified spec
- Updated to simplifying splitting off a php7 package
* Fri Feb  1 2013 aj@ajaissle.de
- Improved spec to serve more build targets.
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- need to explicitly include php53-devel to supersede php-macros for SLE11 builds
- SLES 11SP2 compatibility
* Mon Nov 26 2012 Ralf Lang <lang@b1-systems.de>
- version 1.0.6
  Bug #18856: Authentication warnings because of wrong Auth_SASL::factory argument [kguest]
  Added basic support for any mechanism of the SCRAM family; with thanks to Jehan Pagès. [kguest]
  crammd5 and digestmd5 mechanisms name deprecated in favour of IANA registered names 'cram-md5' and 'digest-md5'; with thanks to Jehan Pagès. [kguest]
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Mon Jan 31 2011 lang@b1-systems.de
- BSD license as of pear package statement
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Auth_SASL
- merge with php-pear-auth_sasl, php5-pear-auth_sasl
- changelog to changes file
- added php-macros
* Tue Dec 21 2010 lang@b1-systems.de
- updated to 1.0.4
  * Fix bug #16624: open_basedir restriction warning in
    DigestMD5.php [till]
- dropped php4 support in package
- cleaned up some warnings
* Tue Nov 10 2009 chris@computersalat.de
- new version 1.0.3
  * Move SVN to proper directory structure [cweiske]
  * Fix Bug #8775: Error in package.xml
  * Fix Bug #14671: Security issue due to seeding random number
    generator [cweiske]
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint fixes
* Tue May 19 2009 chris@computersalat.de
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- removed 1.0.1 source
* Tue Jun 13 2006 suse-tux@gmx.de
- updated to version 1.0.2
- added rpmmacros (changed "mv" to "%%__mv" etc.)
- removed #usedforbuild, added %%clean-macro
- made spec file portable for older/newer suse_versions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mmarek@suse.de
- fix filelist, remove temporary files created by pear installer
- unify php5-pear-*.spec files
- increase php's memory_limit during installation (parsing
  xml needs more than default 8M sometimes)
* Mon Jan 16 2006 mmarek@suse.cz
- created package to satisfy horde dependencies
